PySCeS main authors are [Brett Olivier](https://research.vu.nl/en/persons/bg-olivier)
and [Johann Rohwer](https://github.com/jmrohwer) and in particular, PySCeS founding
father [Jannie Hofmeyr]().

We would also like to acknowledge everyone who has contributed to PySCeS and would like
to thank the following (in alphabetical order):

* Evert Bosdriesz
* James Dominy
* Jannie Hofmeyr
* Morgan Hough
* Jonathan Karr
* Ruchir Khandelwal
* Charl Moller
* Danie Palm
* Herbert Sauro
* Lafras Uys

In addition we would like to acknowledge financial support from the following funding
organisations:

* The South African National Bioinformatics Network (2003-2008)
* The South African National Research Foundation (2000-2004)

© Brett G. Olivier & Johann M. Rohwer, August 2021
